meta_package_manager.managers.gem — Meta Package Manager 2.4.1 documentation

# `meta_package_manager.managers.gem`

class `meta_package_manager.managers.gem.` `Gem`

  Bases: `meta_package_manager.base.PackageManager`

  `HOMEBREW_PATH` = u'/usr/local/bin/gem'
  `SYSTEM_PATH` = u'/usr/bin/gem'
  `platforms` = frozenset([u'macos'])
  `get_version`()

    Fetch version from `gem --version` output.

  `cli_path`
  `name` = u'Ruby Gems'
  `installed`

    Fetch installed packages from `gem list` output.

    Raw CLI output samples:

        $ gem list

        *** LOCAL GEMS ***

        bigdecimal (1.2.0)
        CFPropertyList (2.2.8)
        io-console (0.4.2)
        json (1.7.7)
        libxml-ruby (2.6.0)
        molinillo (0.5.4, 0.4.5, 0.2.3)
        nokogiri (1.5.6)
        psych (2.0.0)
        rake (0.9.6)
        rdoc (4.0.0)
        sqlite3 (1.3.7)
        test-unit (2.0.0.0)

  `outdated`

    Fetch outdated packages from `gem outdated` output.

    Raw CLI output samples:

        $ gem outdated
        did_you_mean (1.0.0 < 1.0.2)
        io-console (0.4.5 < 0.4.6)
        json (1.8.3 < 2.0.1)
        minitest (5.8.3 < 5.9.0)
        power_assert (0.2.6 < 0.3.0)
        psych (2.0.17 < 2.1.0)

  `upgrade_cli`(package_id=None)
  `upgrade_all_cli`()